@@ -1,4 +1,5 @@
 """Windows GUI."""
+# pylint: disable=too-many-lines
 import os.path
 import sys
 import threading
@@ -29,6 +30,7 @@ from tkinter import (
 )
 
 from func_timeout import FunctionTimedOut, func_timeout
+
 from scm_helper.api import API
 from scm_helper.config import (
     BACKUP_DIR,
@@ -117,6 +119,8 @@ class ScmGui:
         self.button_analyse = Button(top_frame, text=msg, command=self.analyse_window)
         self.button_analyse.grid(row=0, column=2, pady=10, padx=10)
 
+        self.master.bind("<Return>", self.analyse_enter)
+
         self.button_backup = Button(top_frame, text="Backup", command=self.backup)
         self.button_backup.grid(row=0, column=3, pady=10, padx=10)
 
@@ -138,6 +142,7 @@ class ScmGui:
 
     def create_menu(self):
         """Create Menus."""
+        # pylint: disable=too-many-statements
         menubar = Menu(self.master)
         file = Menu(menubar, tearoff=0)
         file.add_command(label="Open Archive", command=self.open_archive)
@@ -150,8 +155,10 @@ class ScmGui:
         cmd.add_command(label="Edit Config", command=self.edit_config)
         self.menus.append([cmd, "Edit Config"])
         cmd.add_separator()
-        cmd.add_command(label="Create Lists", command=self.create_lists, state=DISABLED)
-        self.menus.append([cmd, "Create Lists"])
+        cmd.add_command(
+            label="Create / Update Lists", command=self.create_lists, state=DISABLED
+        )
+        self.menus.append([cmd, "Create / Update Lists"])
 
         cmd.add_command(label="Fix Errors", command=self.fixit, state=DISABLED)
         self.menu_fixit = [cmd, "Fix Errors"]
@@ -178,6 +185,14 @@ class ScmGui:
         cmd.add_command(label="List Coaches", command=self.coaches, state=DISABLED)
         self.menus.append([cmd, "List Coaches"])
 
+        label = "Show Swimmers Covid Declaration per session"
+        cmd.add_command(label=label, command=self.covid, state=DISABLED)
+        self.menus.append([cmd, label])
+
+        label = "List Swimmers sessions"
+        cmd.add_command(label=label, command=self.sessions, state=DISABLED)
+        self.menus.append([cmd, label])
+
         label = "Show Not-confirmed Emails"
         cmd.add_command(label=label, command=self.confirm, state=DISABLED)
         self.menus.append([cmd, label])
@@ -331,6 +346,28 @@ class ScmGui:
         self.notify_text.config(state=DISABLED)
         self.report_window.lift()
 
+    def covid(self):
+        """Covid Report."""
+        if self.prep_report() is False:
+            return
+
+        output = wrap(None, self.scm.sessions.print_swimmers_covid)
+        self.report_text.insert(END, output)
+        self.report_text.config(state=DISABLED)
+        self.notify_text.config(state=DISABLED)
+        self.report_window.lift()
+
+    def sessions(self):
+        """Swimmers per Sessions Report."""
+        if self.prep_report() is False:
+            return
+
+        output = wrap(None, self.scm.members.print_swimmers_sessions)
+        self.report_text.insert(END, output)
+        self.report_text.config(state=DISABLED)
+        self.notify_text.config(state=DISABLED)
+        self.report_window.lift()
+
     def edit_config(self):
         """Edit Config."""
         home = str(Path.home())
@@ -359,6 +396,11 @@ class ScmGui:
 
         self.thread = AnalysisThread(self, False).start()
 
+    def analyse_enter(self, event):
+        """Window for analysis result."""
+        debug(f"Event: {event}", 7)
+        self.analyse_window()
+
     def fix_search(self):
         """Window for reports."""
         if self.thread:
@@ -414,10 +456,16 @@ class ScmGui:
         top_frame = Frame(self.report_window)
         top_frame.grid(row=0, column=0, sticky=W + E)
 
+        txt = "Report..."
+        top_group = LabelFrame(self.report_window, text=txt, pady=5, padx=5)
+        top_group.grid(row=0, column=0, pady=10, padx=10, sticky=NSEW)
+
         self.report_window.columnconfigure(0, weight=1)
         self.report_window.rowconfigure(0, weight=1)
+        top_group.columnconfigure(0, weight=1)
+        top_group.rowconfigure(0, weight=1)
 
-        self.report_text = scrolledtext.ScrolledText(top_frame, width=80, height=40)
+        self.report_text = scrolledtext.ScrolledText(top_group, width=80, height=40)
         self.report_text.grid(row=0, column=0, sticky=NSEW)
 
         self.report_window.protocol("WM_DELETE_WINDOW", self.close_report_window)
@@ -445,7 +493,10 @@ class ScmGui:
         all_reports = ["All Reports"] + rpts
 
         menu = OptionMenu(
-            top_frame, self.reports, *all_reports, command=self.process_issue_option,
+            top_frame,
+            self.reports,
+            *all_reports,
+            command=self.process_issue_option,
         )
         menu.grid(row=0, column=1, pady=10, padx=10)
 
@@ -470,7 +521,6 @@ class ScmGui:
 
         self.issue_window.columnconfigure(0, weight=1)
         self.issue_window.rowconfigure(1, weight=1)
-
         top_group.columnconfigure(0, weight=1)
         top_group.rowconfigure(0, weight=1)
 
@@ -595,7 +645,7 @@ class AnalysisThread(threading.Thread):
                 return
         else:
             if wrap(None, self.scm.get_data, False) is False:
-                messagebox.showerror("Analsyis", "Failed to read data")
+                messagebox.showerror("Analysis", "Failed to read data")
                 self.gui.master.after(AFTER, self.gui.set_normal)
                 self.gui.thread = None
                 return
@@ -676,7 +726,7 @@ class FacebookThread(threading.Thread):
         """Process a Facebook report."""
 
         fbook = Facebook()
-        if fbook.read_data(self.scm) is False:
+        if wrap(None, fbook.read_data, self.scm) is False:
             messagebox.showerror("Error", "Could not read facebook files")
             self.gui.report_text.config(state=DISABLED)
             self.gui.notify_text.config(state=DISABLED)
@@ -952,7 +1002,6 @@ def wrap(xtime, func, arg=None):
         messagebox.showerror("Error", msg)
         return False
 
-    # pylint: disable=bad-continuation
     except (
         AssertionError,
         AttributeError,
@@ -961,8 +1010,9 @@ def wrap(xtime, func, arg=None):
         TypeError,
         ValueError,
     ) as err:
-        errmsg = traceback.format_exc(10)
-        debug(errmsg, 1)
+        errmsg = f"\nSCM Helper Version: {VERSION}.\n"
+        errmsg += traceback.format_exc(10)
+        debug(errmsg, 0)
         msg = f"Internal SCM Helper Error:\n{err}\nPlease log an issue on github.\n"
         wrap_trace()
         messagebox.showerror("Error", msg)
