@@ -135,6 +135,11 @@ E_NAME_CAPITAL = {
     MESSAGE: "Check name capitilisation",
     REVERSE: False,
     REPORT: R_MEMBER}
+E_MAX_SESSIONS = {
+    NAME: "E_MAX_SESSIONS",
+    MESSAGE: "Maximum number of sessions permitted exceeded",
+    REVERSE: False,
+    REPORT: R_SESSION}
 E_NEVERSEEN = {
     NAME: "E_NEVERSEEN",
     MESSAGE: "Never seen",
@@ -230,6 +235,11 @@ E_NO_SWIMMERS = {
     MESSAGE: "No swimmers",
     REVERSE: False,
     REPORT: R_SESSION}
+E_TOO_MANY_SWIMMERS = {
+    NAME: "E_TOO_MANY_SWIMMERS",
+    MESSAGE: "Max swimmers exceeded",
+    REVERSE: False,
+    REPORT: R_SESSION}
 E_NOT_A_COACH = {
     NAME: "E_NOT_A_COACH",
     MESSAGE: "Not a coach, but in coach role",
@@ -614,10 +624,10 @@ def print_dict(xdict, reports):
             inner_match = False
             first = True
             length = len(xdict[key1][key2])
+
             for xissue in sorted(
-                    xdict[key1][key2],
-                    key=lambda x: "None" if x[0] is None else x[0]
-                ):
+                xdict[key1][key2], key=lambda x: "None" if x[0] is None else x[0]
+            ):
                 val1, val2, rpt, rev, _ = xissue
                 if (first and rev) or (first and (length > 1)):
                     to_print += "\n"
